from setuptools import setup

setup(
    author="CS50",
    author_email="sysadmins@cs50.harvard.edu",
    classifiers=["Topic :: Utilities"],
    description="This is CS50 style.",
    keywords="style50",
    name="style50",
    url="https://github.com/cs50/style50"
)
